# mc-mod-getter [![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT) [![Package Pypi](https://img.shields.io/pypi/v/notyet.svg)](https://pypi.org/project/notyet)

Utility to download minecraft mods from the internet
